Bifrost: Data Fields

Bifrost

Here is a list of all documented struct and union fields with links to the struct/union documentation for each field:

### - c -

- clear() : CCDBG_Data_t< Unitig_data_t > , CDBG_Data_t< Unitig_data_t, Graph_data_t > , ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t > , UnitigColors
- clipTips : CDBG_Build_opt
- ColoredCDBG() : ColoredCDBG< Unitig_data_t >
- colorMax() : UnitigColors
- CompactedDBG() : CompactedDBG< Unitig_data_t, Graph_data_t >
- concat() : CCDBG_Data_t< Unitig_data_t > , CDBG_Data_t< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t >
- const_iterator : CompactedDBG< Unitig_data_t, Graph_data_t > , UnitigColors
- contains() : UnitigColors